summaryrefslogtreecommitdiff
path: root/drawinglayer
diff options
context:
space:
mode:
authorLuboš Luňák <l.lunak@collabora.com>2022-08-31 17:54:34 +0200
committerLuboš Luňák <l.lunak@collabora.com>2022-09-01 12:01:51 +0200
commit0b6520c4acbfbb656f00d0fab11289899614494f (patch)
treed76974c6e57200e0583311a4e4badc18a418f7f4 /drawinglayer
parent0415aa11f66de0c64f1ed524197bfea70fe3c3ca (diff)
explicitly use BmpScaleFlag::NearestNeighbor when wanted
That is the algorithm that doesn't change colors, BmpScaleFlag::Fast works the same way only because it's mapped to this algorithm (which may not necessarily be the case forever). Change-Id: Ibebfff668eaa1da93963f8e8601fec51cfdfca34 Reviewed-on: https://gerrit.libreoffice.org/c/core/+/139128 Tested-by: Jenkins Reviewed-by: Luboš Luňák <l.lunak@collabora.com>
Diffstat (limited to 'drawinglayer')
-rw-r--r--drawinglayer/source/primitive2d/GlowSoftEgdeShadowTools.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/drawinglayer/source/primitive2d/GlowSoftEgdeShadowTools.cxx b/drawinglayer/source/primitive2d/GlowSoftEgdeShadowTools.cxx
index 0cc5be1bd532..da3621aa189c 100644
--- a/drawinglayer/source/primitive2d/GlowSoftEgdeShadowTools.cxx
+++ b/drawinglayer/source/primitive2d/GlowSoftEgdeShadowTools.cxx
@@ -50,8 +50,8 @@ AlphaMask ProcessAndBlurAlphaMask(const Bitmap& rMask, double fErodeDilateRadius
aSize.setWidth(aSize.Width() / 2);
}
- // BmpScaleFlag::Fast is important for following color replacement
- mask.Scale(fScale, fScale, BmpScaleFlag::Fast);
+ // BmpScaleFlag::NearestNeighbor is important for following color replacement
+ mask.Scale(fScale, fScale, BmpScaleFlag::NearestNeighbor);
if (fErodeDilateRadius > 0)
BitmapFilter::Filter(mask, BitmapDilateFilter(fErodeDilateRadius));